@@ -99,4 +99,12 @@ def test_utils_download():
         download("fail")
     except Exception:
         return
-    assert False
\ No newline at end of file
+    assert False
+
+
+def test_travel_outward():
+    from text_models.place import Travel
+    from datetime import datetime
+    travel = Travel(window=4)
+    matrix = travel.outward(travel.country)
+    assert matrix[-1]["MX"]
\ No newline at end of file
